<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<?php if( @$this->form ): ?>
  <?php echo $this->form->render($this) ?>
<?php endif; ?>

<?php if( @$this->status ): ?>
  <script type="text/javascript">
    setTimeout(function() {
      parent.Smoothbox.close();
      setTimeout(function() {
        parent.window.location.replace( parent.window.location.href );
      }, 250);
    }, 1000);
  </script>
<?php endif; ?>
