<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Network_Form_Admin_Global extends Engine_Form {

  public function init() {

    $settings = Engine_Api::_()->getApi('settings', 'core');
    $this->setTitle('Global Settings')
        ->setDescription('These settings affect all members in your community.');

    $this->addElement('Radio', "network_enable", array(
      'label' => 'Enable Networks',
      'description' => 'Do you want to enable networks for your website?',
      'multiOptions' => array(
          '1' => 'Yes',
          '0' => 'No',
      ),
      'value' => $settings->getSetting('network.enable', 1),
    ));

    // init submit
    $this->addElement('Button', 'submit', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true,
    ));
  }
}
