<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class="global_form_popup">
  <div class="admin_member_list">
    <h3><?php echo $this->translate('Network Members');?></h3>
    <ul>
      <?php foreach( $this->members as $membership ):
        if( !isset($this->memberUsers[$membership->user_id]) ) continue;
        $member = $this->memberUsers[$membership->user_id];
        ?>
        <li>
          <?php echo $this->htmlLink($member->getHref(), $this->itemPhoto($member, 'thumb.icon'), array('class' => 'profile_friends_icon','target'=>'_blank')) ?>
          <?php echo $this->htmlLink($member->getHref(), $member->getTitle(),array('target'=>'_blank')) ?>
        </li>
      <?php endforeach;?>
    </ul>
  </div>
  <div class="admin_member_list_footer">
    <?php echo $this->paginationControl($this->members, null, null, array('query' => array('format'=>'smoothbox'))); ?>
    <button type="submit" onclick="parent.Smoothbox.close();return false;" name="close_button" value="Close"><?php echo $this->translate("Close"); ?></button>
  </div>
</div>
