UPDATE `engine4_core_menuitems` SET `params` = '{"route":"user_extended", "module":"user", "controller":"settings", "action":"network", "icon":"fi fi-rr-globe"}' WHERE `engine4_core_menuitems`.`name` = 'user_settings_network';