<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<div class='clear'>
    <div class='form box admin_search'>
      <form action="<?php echo $this->url(array('action' => 'index')) ?> ">
      <div>
        <input type='text' class='text' name='search'>
      </div>
      <div>      
        <div class='buttons'>
          <button type='submit'><?php echo $this->translate("Search") ?></button>
        </div>
      </div>
      </form>
    </div>
  </div>
