
/* $Id: mobile.css 8825 2011-04-09 01:34:20Z john $ */



/*
NETWORK SETTINGS
Used to style the networks page in the member's
settings area.
*/
.networks_left{
  float:left;
  width: 380px;
  padding-right: 30px;
}
[dir="rtl"] .networks_left{
  float: right;
  padding-right: 0px;
  padding-left: 30px;
}
.networks_right{
  float:left;
  width: 380px;
}
[dir="rtl"] .networks_right{
  float: right;
}
ul.networks{
  width: 350px;
  margin: 15px 0px 15px 0px;
}
ul.networks > li{
  overflow: hidden;
  border: 1px solid var(--theme-border-color);
  padding: 10px;
  display:flex;
  align-items:center;
  justify-content:flex-start;
}
ul.networks > li + li{
  border-top:none;
}
ul.networks > li > div{
  float: left;
  overflow: hidden;
  font-weight: bold;
}
ul.networks > li > div > span{
  font-weight: normal;
  font-size: .8em;
}
ul.networks > li > a{
  display: block;
  overflow: hidden;
  margin-left:5px;
}
[dir="rtl"] ul.networks > li > a {
  text-align:left;
  margin-left:0;
  margin-right:5px;
}
/* USER NETWORK SETTINGS */
form#network-form input.network_join_selected
{
  background-color: #eee;
}
/* ITEM TYPE ICONS */
.item_icon_network:before
{
  content: "\\f0ac";
	font-weight: 900;
}
